#
# This script was written by George A. Theall, <theall@tifaware.com>.
#
# See the Nessus Scripts License for details.
#


if (description) {
  script_id(13648);
  script_version ("$Revision: 1.1 $");
  script_cve_id("CAN-2004-0613");

  name["english"] = "osTicket Attachment Viewing Vulnerability";
  script_name(english:name["english"]);
 
  desc["english"] = "
The target host is running a version of osTicket that enables a remote
user to view attachments associated with existing tickets from any user. 
These attachments may contain sensitive information. 

Solution : Upgrade to osTicket STS 1.2.7 or later.
Risk factor : Low";
  script_description(english:desc["english"]);
 
  summary["english"] = "Checks for Attachment Viewing Vulnerability in osTicket";
  script_summary(english:summary["english"]);
 
  script_category(ACT_ATTACK);
  script_copyright(english:"This script is Copyright (C) 2004 George A. Theall");

  family["english"] = "CGI abuses";
  script_family(english:family["english"]);

  script_dependencie("http_version.nasl");
  script_require_ports("Services/www", 80);

  exit(0);
}

include("global_settings.inc");
include("http_func.inc");
include("http_keepalive.inc");

host = get_host_name();
if (! host) host = string("[", get_host_ip(), "]");
port = get_http_port(default:80);
if (debug_level) display("debug: testing ", host, ":", port, ".\n");

if (!get_port_state(port)) exit(0);
if (!can_host_php(port:port)) exit(0);

# Search for osTicket in a couple of different locations.
#
# NB: Directories beyond cgi_dirs() come from a Google search - 
#     "inurl:open.php osticket" - and represent the more popular
#     installation paths currently. Still, cgi_dirs() should catch
#     the directory if its referenced elsewhere on the target.
dirs = make_list(
  "", 
  "/osticket", 
  "/helpdesk", 
  "/soporte", 
  "/support", 
  "/ticket",
  cgi_dirs()
);
foreach dir (dirs) {
  # Try to browse osTicket's attachments directory.
  url = string(dir, "/attachments/");
  if (debug_level) display("debug: checking ", url, ".\n");
  req = http_get(item:url, port:port);
  res = http_keepalive_send_recv(port:port, data:req);
  if (res == NULL) exit(0);           # can't connect
  if (debug_level) display("debug: res =>>", res, "<<\n");

  # If successful, there's a problem.
  if (egrep(pattern:"200 OK", string:res, icase:TRUE)) {
    security_warning(port:port);
    exit(0);
  }
}
