#
# This script was written by George A. Theall, <theall@tifaware.com>.
#
# See the Nessus Scripts License for details.
#


# NB: I define the script description here so I can later modify
#     it with the version number and install directory.
  desc["english"] = "
This script detects whether the remote host is running SquirrelMail and
extracts its version number if so.

SquirrelMail is a PHP-based webmail package that provides access to mail
accounts via POP3 or IMAP; see <http://www.squirrelmail.org/> for more
information. 

Risk factor : None";


if (description) {
  script_id(12647);
  script_version ("$Revision: 1.2 $");
 
  name["english"] = "SquirrelMail Detection";
  script_name(english:name["english"]);
 
  script_description(english:desc["english"]);
 
  summary["english"] = "Checks for the presence of SquirrelMail";
  script_summary(english:summary["english"]);
 
  script_category(ACT_GATHER_INFO);
  script_copyright(english:"This script is Copyright (C) 2004 George A. Theall");

  family["english"] = "General";
  script_family(english:family["english"]);

  script_dependencie("http_version.nasl");
  script_require_ports("Services/www", 80);

  exit(0);
}

include("global_settings.inc");
include("http_func.inc");
include("http_keepalive.inc");

host = get_host_name();
port = get_http_port(default:80);
if (debug_level) display("debug: looking for SquirrelMail on ", host, ":", port, ".\n");

if (!get_port_state(port)) exit(0);
if (!can_host_php(port:port)) exit(0);

# Search for SquirrelMail in a couple of different locations.
#
# NB: Directories beyond cgi_dirs() come from a Google search - 
#     'intitle:login squirrelmail' - and represent the more popular
#     installation paths currently. Still, cgi_dirs() should catch
#     the directory if its referenced elsewhere on the target.
dirs = make_list("", "/squirrelmail", "/webmail", "/mail", "/sm", cgi_dirs());
foreach d (dirs) {
  # Search in a couple of different pages.
  files = make_list(
    "/src/login.php", "/src/compose.php", "/ChangeLog", "/ReleaseNotes"
  );
  foreach f (files) {
    if (debug_level) display("debug: testing ", d, f, " on port ", port, "...\n");

    # Get the page.
    req = http_get(item:string(d, f), port:port);
    res = http_keepalive_send_recv(port:port, data:req);
    if (res == NULL) exit(0);           # can't connect
    if (debug_level) display("debug: res =>>", res, "<<\n");

    if ("200 OK" >< res) {
      # Specify pattern used to identify version string.
      if (f == "/src/login.php" || f == "/src/compose.php") {
        pat = "<SMALL>SquirrelMail version (.+)<BR";
      }
      else if (f == "/ChangeLog") {
        pat = "^Version (.+) - [0-9]";
      }
      # nb: this first appeared in 1.2.0 and isn't always accurate.
      else if (f == "/ReleaseNotes") {
        pat = "Release Notes: SquirrelMail (.+) *\*";
      }
      # - someone updated files but forgot to add a pattern???
      else {
        display("Don't know how to handle file '", f, "'!\n");
        exit(1);
      }

      # Get the version string.
      if (debug_level) display("debug: grepping results for =>>", pat, "<<\n");
      matches = egrep(pattern:pat, string:res, icase:TRUE);
      foreach match (split(matches)) {
        match = chomp(match);
        if (debug_level) display("debug: grepping >>", match, "<< for =>>", pat, "<<\n");
        vers = eregmatch(pattern:pat, string:match, icase:TRUE);
        if (vers == NULL) break;
        vers = vers[1];
        if (debug_level) display("debug: SquirrelMail version =>>", vers, "<<\n");

        desc = ereg_replace(
          string:desc["english"],
          pattern:"This script[^\.]+\.", 
          replace:string("The remote host is running SquirrelMail ", vers, " under ", d, ".")
        );
        security_note(port:port, data:desc);

        set_kb_item(name:string("www/", port, "/squirrelmail/version"), value:vers);
        set_kb_item(name:string("www/", port, "/squirrelmail/location"), value:d);

        # No sense testing any further since we got the version number.
        exit(0);
      }
    }
  }
}
