#
# This script was written by George A. Theall, <theall@tifaware.com>.
#
# See the Nessus Scripts License for details.
#

if (description) {
  script_id(12281);
  script_version ("$Revision: 1.1 $");

  script_bugtraq_id(10531);
  if (defined_func("script_xref")) {
    script_xref(name:"GLSA", value:"GLSA 200406-09");
    script_xref(name:"OSVDB", value:"7005");
  }

  name["english"] = "Chora Remote Code Execution Vulnerability";
  script_name(english:name["english"]);

  desc["english"] = "
The remote server is running a version of Chora (a PHP-based interface
to CVS repositories from the Horde Project) strictly less than 1.2.2. 
Such versions have a flaw in the diff viewer that enables a remote
attacker to upload code and run it with the permissions of the PHP
script. 

*** Nessus has determined the vulnerability exists on the target
*** simply by looking at the version number of Chora installed there; it has
*** not attempted to actually exploit the vulnerability. 

See also : http://security.e-matters.de/advisories/102004.html
Solution : Upgrade to Chora version 1.2.2 or later.
Risk factor : High";
  script_description(english:desc["english"]);
 
  summary["english"] = "Checks for remove code execution vulnerability in Chora";
  script_summary(english:summary["english"]);
 
  script_category(ACT_GATHER_INFO);
  script_copyright(english:"This script is Copyright (C) 2004 George A. Theall");

  family["english"] = "CGI abuses";
  script_family(english:family["english"]);

  script_dependencie("http_version.nasl");
  script_require_ports("Services/www", 80);

  exit(0);
}

include("http_func.inc");
include("http_keepalive.inc");

debug = 0;

port = get_http_port(default:80);
if (!get_port_state(port)) exit(0);

if (!can_host_php(port:port)) exit(0);

# Search for page in a couple of different locations in addition to cgi_dirs().
dirs = make_list("/horde/chora", "/cvs/horde/chora", cgi_dirs());
foreach d (dirs) {
  # Search in a couple of different pages.
  files = make_list(
    "/horde/services/help/?module=chora&show=about",
    "/",
    "/cvs.php",
    "/README"
  );
  foreach f (files) {
    if (debug) display("debug: testing ", d, f, "...\n");

    # Get the page.
    req = http_get(item:string(d, f), port:port);
    res = http_keepalive_send_recv(port:port, data:req);
    if (res == NULL) exit(0);           # can't connect
    if (debug) display("debug: res =>>", res, "<<\n");
    if (egrep(pattern:"404 Not Found", string:res, icase:TRUE)) break;

    # Specify pattern used to identify version string.
    #
    # - version 2.x
    if (f = "/horde/services/help/?module=chora&show=about") {
      pat = ">This is Chora +(.+)\.<";
    }
    # - version 1.x
    else if (f =~ "^/cvs.php") {
      pat = "class=.+>CHORA +(.+)</a>";
    }
    # - other possibilities, but not necessarily good ones.
    #   nb: README is not guaranteed to be available and is sometimes
    #       inaccurate (eg, it reads 1.0 in version 1.2 and 1.2.1 in
    #       version 1.2.2).
    else if (f = "/README") {
      pat = "^Version +(.+) *$";
    }
    # - someone updated files but forgot to add a pattern???
    else {
      display("Don't know how to handle file '", f, "'!\n");
      exit(1);
    }

    # Get the version string.
    if (debug) display("debug: grepping results for =>>", pat, "<<\n");
    matches = egrep(pattern:pat, string:res);
    if (!matches) break;
    foreach match (split(matches)) {
      match = chomp(match);
      if (debug) display("debug: grepping >>", match, "<< for =>>", pat, "<<\n");
      vers = eregmatch(pattern:pat, string:match);
      if (vers == NULL) break;
      if (debug) display("debug: version =>>", vers[1], "<<\n");

      if (ereg(pattern:"^(0\.|1\.(0\.|1\.|2|2\.1))(-(cvs|ALPHA))$", string:vers[1])) security_hole(port);

      # No sense testing any further since we got the version number.
      exit(0);
    }
  }
}
